@@ -16,7 +16,7 @@ limitations under the License.
 
 import os
 import re
-from typing import Dict, List, Tuple
+from typing import Dict, List, Tuple, Union
 import unicodedata
 from builtins import str as unicode
 import nltk
@@ -88,7 +88,7 @@ class G2p:
         self.tagger = PerceptronTagger(load=False)
         tagger_path = os.path.join(resources_path, "id_posp_tagger.pickle")
         self.tagger.load("file://" + tagger_path)
-        self.model = BERT() if model_type == "BERT" else LSTM()
+        self.model: Union[BERT, LSTM] = BERT() if model_type == "BERT" else LSTM()
         self.pos_dict = {
             "N": ["B-NNO", "B-NNP", "B-PRN", "B-PRN", "B-PRK"],
             "V": ["B-VBI", "B-VBT", "B-VBP", "B-VBL", "B-VBE"],
@@ -110,6 +110,7 @@ class G2p:
         Returns:
             str: Preprocessed text.
         """
+        text = text.replace("-", " ")
         text = " ".join(word_tokenize(text))
         text = unicode(text)
         text = "".join(
@@ -119,7 +120,7 @@ class G2p:
         )
         text = self.normalizer.normalize(text).strip()
         text = text.lower()
-        text = re.sub("[^ a-z'.,?!\-]", "", text)
+        text = re.sub(r"[^ a-z'.,?!\-]", "", text)
         return text
 
     def _rule_based_g2p(self, text: str) -> str:
@@ -132,21 +133,22 @@ class G2p:
             str: Phoneme string.
         """
         _PHONETIC_MAPPING = {
-            "kh": "x",
             "ny": "ɲ",
             "ng": "ŋ",
             "sy": "ʃ",
-            "c": "tʃ",
-            "g": "ɡ",
-            "j": "dʒ",
-            "q": "k",
-            "x": "ks",
-            "y": "j",
-            "'": "ʔ",
             "aa": "aʔa",
             "ii": "iʔi",
             "oo": "oʔo",
             "əə": "əʔə",
+            "uu": "uʔu",
+            "'": "ʔ",
+            "g": "ɡ",
+            "q": "k",
+            "j": "dʒ",
+            "y": "j",
+            "x": "ks",
+            "c": "tʃ",
+            "kh": "x",
         }
 
         _CONSONANTS = "bdjklmnprstwɲ"
@@ -157,6 +159,9 @@ class G2p:
         if text.startswith("x"):
             text = "s" + text[1:]
 
+        if text.startswith("ps"):
+            text = text[1:]
+
         for g, p in _PHONETIC_MAPPING.items():
             text = text.replace(g, p)
 
@@ -169,7 +174,7 @@ class G2p:
         ]
         return " ".join([p for phn in phonemes for p in phn])
 
-    def __call__(self, text: str) -> List[str]:
+    def __call__(self, text: str) -> List[List[str]]:
         """Grapheme-to-phoneme converter.
 
         1. Preprocess and normalize text
@@ -184,7 +189,7 @@ class G2p:
             text (str): Grapheme text to convert to phoneme.
 
         Returns:
-            List[str]: List of strings in phonemes.
+            List[List[str]]: List of strings in phonemes.
         """
         text = self._preprocess(text)
         words = word_tokenize(text)
